@@ -28,8 +28,8 @@ def dotraining(maadstoken,thefile,autofeature,removeoutliers,hasseasonality,depe
    if hasseasonality != 1 and hasseasonality != 0:
       return "ERROR: Incorrect hasseasonality value value: 1,0"
       
-   if trainingpercentage<=40 or trainingpercentage>=100:
-      return "ERROR: Incorrect training percentage value: Must be between 40 and 100"
+   if trainingpercentage<40 or trainingpercentage>100:
+      return "ERROR: Incorrect training percentage value: Must be between 40 and 100, inclusive"
    if hasseasonality:
       if len(summer)==0 or len(winter)==0 or len(shoulder)==0:
          return "ERROR: Summer, Winter and Shoulder must contain month values."
