@@ -180,18 +180,18 @@ def viperproducetotopic(vipertoken,host,port,topic,producerid,enabletls=0,inputd
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperconsumefromtopic(vipertoken,host,port,topic,consumerid,companyname,enabletls=0,offset=0,brokerhost='',brokerport=-999,microserviceid=''):
+def viperconsumefromtopic(vipertoken,host,port,topic,consumerid,companyname,enabletls=0,delay=100,offset=0,brokerhost='',brokerport=-999,microserviceid=''):
 
     if len(host)==0 or len(vipertoken)==0 or port==-999 or len(topic)==0 or len(consumerid)==0 or len(companyname)==0:
          return "Please enter host,port,vipertoken,topic, consumerid,companyname"
         
     value=("consumefromtopic?vipertoken="+vipertoken + "&topic="+topic + "&consumerid=" + consumerid + "&offset="+str(offset) +
-          "&enabletls=" + str(enabletls) + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport)+"&companyname="+companyname)
+        "&delay=" + str(delay) +  "&enabletls=" + str(enabletls) + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport)+"&companyname="+companyname)
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,enabletls=0,hpdeport=-999,brokerhost='',brokerport=9092,
+def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,enabletls=0,delay=0,hpdeport=-999,brokerhost='',brokerport=9092,
                      timeout=120,usedeploy=0,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
@@ -201,12 +201,12 @@ def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,cons
          return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
         
     value=("viperhpdepredict?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-           "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&usedeploy=" +str(usedeploy) +"&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
+           "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&usedeploy=" +str(usedeploy) +"&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,enabletls=0,hpdeport=-999,usedeploy=0,
+def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,enabletls=0,delay=100,hpdeport=-999,usedeploy=0,
                       ismin=1,constraints='best',stretchbounds=20,constrainttype=1,epsilon=10,brokerhost='',brokerport=9092,
                      timeout=120,microserviceid=''):
 
@@ -217,7 +217,7 @@ def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,con
          return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
         
     value=("viperhpdeoptimize?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-          "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport))
+         "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
@@ -238,17 +238,17 @@ def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,con
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperproducetotopicstream(vipertoken,host,port,topic,producerid,offset,enabletls=0,brokerhost='',brokerport=-999,microserviceid=''):
+def viperproducetotopicstream(vipertoken,host,port,topic,producerid,offset,enabletls=0,delay=100,brokerhost='',brokerport=-999,microserviceid=''):
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(topic)==0 or len(producerid)==0):
          return "Please enter host,port,vipertoken,topic,producerid"
         
-    value=("producetotopicstream?vipertoken="+vipertoken + "&topicname="+topic + "&enabletls="+str(enabletls) +"&brokerhost="+brokerhost + "&brokerport="+str(brokerport) + "&producerid="+producerid + "&offset="+str(offset))
+    value=("producetotopicstream?vipertoken="+vipertoken + "&topicname="+topic + "&delay=" + str(delay) + "&enabletls="+str(enabletls) +"&brokerhost="+brokerhost + "&brokerport="+str(brokerport) + "&producerid="+producerid + "&offset="+str(offset))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
 def vipercreatetrainingdata(vipertoken,host,port,consumefrom,produceto,dependentvariable,independentvariables,
-                            consumerid,producerid,offset,companyname,enabletls=0,maxrows=-1,brokerhost='',brokerport=-999,microserviceid=''):
+                            consumerid,producerid,offset,companyname,enabletls=0,delay=100,maxrows=-1,brokerhost='',brokerport=-999,microserviceid=''):
 
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(consumefrom)==0 or len(produceto)==0 or len(dependentvariable)==0 or
         len(independentvariables)==0 or len(companyname)==0 or len(consumerid)==0 or len(producerid)==0):
@@ -256,7 +256,7 @@ def vipercreatetrainingdata(vipertoken,host,port,consumefrom,produceto,dependent
         
     value=("createtrainingdata?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto="+produceto +
            "&dependentvariable="+dependentvariable+"&independentvariables="+independentvariables +"&offset="+str(offset)+
-           "&enabletls=" + str(enabletls) + "&consumerid="+consumerid + "&producerid="+producerid+"&companyname="+companyname + "&maxrows="+str(maxrows) + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
+           "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&consumerid="+consumerid + "&producerid="+producerid+"&companyname="+companyname + "&maxrows="+str(maxrows) + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
@@ -273,13 +273,13 @@ def vipercreatetopic(vipertoken,host,port,topic,companyname,contactname,contacte
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperconsumefromstreamtopic(vipertoken,host,port,topic,consumerid,companyname,enabletls=0,offset=0,brokerhost='',brokerport=-999,microserviceid=''):
+def viperconsumefromstreamtopic(vipertoken,host,port,topic,consumerid,companyname,enabletls=0,delay=100,offset=0,brokerhost='',brokerport=-999,microserviceid=''):
 
     if len(host)==0 or len(vipertoken)==0 or port==-999 or len(topic)==0 or len(consumerid)==0 or len(companyname)==0:
          return "Please enter host,port,vipertoken,topic, consumerid,companyname"
         
     value=("consumefromstreamtopic?vipertoken="+vipertoken + "&topic="+topic + "&consumerid=" + consumerid + "&offset="+str(offset) +
-          "&enabletls=" + str(enabletls) + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport)+ "&companyname="+companyname)
+         "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport)+ "&companyname="+companyname)
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
@@ -311,12 +311,12 @@ def vipercreateconsumergroup(vipertoken,host,port,topic,groupname,companyname,co
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperconsumergroupconsumefromtopic(vipertoken,host,port,topic,consumerid,groupid,companyname,enabletls=0,offset=0,brokerhost='',brokerport=-999,microserviceid=''):
+def viperconsumergroupconsumefromtopic(vipertoken,host,port,topic,consumerid,groupid,companyname,enabletls=0,delay=100,offset=0,brokerhost='',brokerport=-999,microserviceid=''):
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(companyname)==0 or len(consumerid)==0 or len(groupid)==0):
          return "Please enter host,port,vipertoken,consumerid,companyname,groupid"
         
     value=("consumergroupconsumefromtopic?vipertoken="+vipertoken + "&topic="+topic + "&consumerid="+consumerid +
-           "&enabletls=" + str(enabletls) + "&brokerhost="+brokerhost+"&brokerport="+str(brokerport) +"&offset="+str(offset) +"&companyname="+companyname+"&groupid="+groupid)
+          "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&brokerhost="+brokerhost+"&brokerport="+str(brokerport) +"&offset="+str(offset) +"&companyname="+companyname+"&groupid="+groupid)
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
